package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````P"4```````!``````````#"Q````
M`````````$``.``+`$``&P`:``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````*@9````````J!D`````````
M$`````````$````%`````"``````````(``````````@````````!3X`````
M```%/@`````````0`````````0````0`````8`````````!@`````````&``
M```````010```````!!%`````````!`````````!````!@```-"K````````
MT+L```````#0NP```````%`$````````T!0`````````$`````````(````&
M````X*L```````#@NP```````."[````````$`(````````0`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````("=````````@)T```````"`G0``
M``````0!````````!`$````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``#0JP```````-"[````````T+L````````P!````````#`$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`$_<+T`L?%')WW=(Z>K0VD!74".1!````!`````!````1TY5```````#
M`````@`````````1````/P````0````(````(!P0``5`!(8H`D`$D(8`A(()
M`"!)(`0(N*(11;H``@H`````/P```$(```!%````1@```$T```!.````4```
M`%0```!5````5P```%@```!;````70```%\``````````````&[%WQ_.WD<M
M:W^:?"[%F[8@_^0.U634?-EQ6!SB1\8!0OK7AZQ+X\"ZXY)\PN4_+/JA;&"S
M`8MO:PE#UF:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`T4XI[:S>.>,V+;[16,
M)<P,.I<+5J2;EJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@^TD`````````
M````````````````````````````X0```!(`````````````````````````
M?@$``!(`````````````````````````Y`$``!(`````````````````````
M````P@$``!(``````````````````````````0```"``````````````````
M````````ZP$``!(`````````````````````````=P(``!(`````````````
M``````````````(``!(`````````````````````````10$``!(`````````
M````````````````7P(``!(`````````````````````````5P(``!(`````
M````````````````````=````!(`````````````````````````3P,``!(`
M````````````````````````W````!(`````````````````````````(P(`
M`!(`````````````````````````%0(``!(`````````````````````````
MTP$``!(`````````````````````````<`(``!(`````````````````````
M````@`(``!(`````````````````````````-P$``!(`````````````````
M````````!0$``!(`````````````````````````<P$``!(`````````````
M````````````CP$``!(`````````````````````````R@$``!(`````````
M````````````````X`(``!(`````````````````````````8`$``!(`````
M````````````````````^0$``!(`````````````````````````L`$``!(`
M````````````````````````Q`(``!(`````````````````````````O0(`
M`!(`````````````````````````$P$``!(`````````````````````````
M'0```"``````````````````````````-P(``!(`````````````````````
M````5````!(`````````````````````````E0$``!(`````````````````
M````````;`$``!(`````````````````````````@P```!(`````````````
M````````````CP```!(`````````````````````````+`$``!(`````````
M````````````````\@```!(`````````````````````````1@```!(`````
M````````````````````Y@```!(`````````````````````````/@(``!(`
M````````````````````````50$``!(`````````````````````````P```
M`!(`````````````````````````\0$``!(`````````````````````````
MJ0$``!(`````````````````````````K@(``!(`````````````````````
M````AP(``!(`````````````````````````8P```!(`````````````````
M````````M@(``!(`````````````````````````#@(``!(`````````````
M````````````I````!(`````````````````````````(P$``!(`````````
M````````````````3`(``!(`````````````````````````O0$``!(`````
M````````````````````M0$``!(`````````````````````````*0(``!(`
M````````````````````````+````"``````````````````````````!P(`
M`!(`````````````````````````'`(``!(`````````````````````````
MH`(``!(`````````````````````````6`,``!(`#@`@0@```````#X!````
M````A`,``!(`#@"@-P```````-4'````````T0(``!(`#@"P(P````````\"
M````````+`,``!(`#@#0+@````````4`````````&`0``!(`#@#@+@``````
M``("````````3@0``!(`#@"`/P```````)T"````````!`0``!``&``@P```
M````````````````:P,``!(`#@#P,````````"4`````````D0,``!(`#@#@
M60```````)\!````````J0,``!$`$```8`````````0`````````Z`,``!``
M&`"@T```````````````````$`0``!(`#@#@+0```````#``````````)00`
M`!(`#@"0-@````````L!````````-P0``!(`#@#P-0```````'0`````````
MG`,``!``%P``P```````````````````>`,``!(`#@`@,0```````!P`````
M````U@(``!$`&`!`P`````````@`````````9`,``!``%P`@P```````````
M````````UP(``"$`&`!`P`````````@`````````W@,``!$`%P`8P```````
M``@`````````:0(``!$`&`!@P`````````@`````````'`,``!(`#@#@70``
M``````$`````````S@,``!(`#@"`70```````%T`````````H@,``!(`#@#`
M)0```````"L`````````100``!(`#@"`60```````%0`````````G@,``"``
M%P``P```````````````````T0```!$`&``@P`````````0`````````V`(`
M`"$`&`!`P`````````@`````````/0,``!(`#@!P-@```````!T`````````
MD0(``"(`````````````````````````N`,``!(`#@`0+@```````+\`````
M````^@,``!(`#@"`6P```````/L!````````LP```!$`&``PP`````````$`
M````````[0,``!(`#@!`,0```````*8$`````````%])5$U?9&5R96=I<W1E
M<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#
M;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A
M=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R
M;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E
M=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E
M=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`%]?97)R;F]?;&]C871I;VX`8VQO<V4`<'1H<F5A9%]G971S<&5C
M:69I8P!O<&5N-C0`<F5A9`!L<V5E:S8T`&5X:70`<W1R;F-M<`!C;&]S961I
M<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?
M9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H
M<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM
M;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N
M`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D
M+G-O+C``;&EB8RYS;RXV`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E
M>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E
M9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H
M85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`
M<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A
M<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H
M85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(N-0!'3$E"
M0U\R+C,N-`!'3$E"0U\R+C$T`$=,24)#7S(N,RXR`$=,24)#7S(N-``````"
M``,``@`"`````@`"``(````"``(````"`````@`"``0``@`"``````````,`
M`@`%`````@`#``(``@``````!@````,``@`````````````````'```````"
M``,``@`"`````@`"```````"``(``P`'`````@`"``<``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`"``$``@`!``(``0`!``$``0`!`````@`!
M``(``0`!`````0`!``$``@,``!`````@````=1II"0```P!D!`````````$`
M!0`2`P``$`````````!T&6D)```'`'`$```0````E)&6!@``!@!\!```$```
M`'(9:0D```4`AP0``!`````4:6D-```$`),$```0````=1II"0```@!D!```
M`````-"[````````"`````````"@)@```````-B[````````"`````````!@
M)@````````C`````````"``````````(P````````!C`````````"```````
M``#@8@```````,"_````````!@````4``````````````,B_````````!@``
M``D``````````````-"_````````!@```!T``````````````-B_````````
M!@```"```````````````."_````````!@```"@``````````````.B_````
M````!@```#(``````````````/"_````````!@```#L``````````````/B_
M````````!@```%P``````````````"#`````````!0```%D`````````````
M`##`````````!0```%\``````````````$#`````````!0```$\`````````
M`````&#`````````!0```%,```````````````B^````````!P````$`````
M`````````!"^````````!P````(``````````````!B^````````!P````,`
M`````````````""^````````!P````0``````````````"B^````````!P``
M``8``````````````#"^````````!P````<``````````````#B^````````
M!P````@``````````````$"^````````!P````H``````````````$B^````
M````!P````L``````````````%"^````````!P````P``````````````%B^
M````````!P````T``````````````&"^````````!P````X`````````````
M`&B^````````!P````\``````````````'"^````````!P```!``````````
M`````'B^````````!P```!$``````````````("^````````!P```!(`````
M`````````(B^````````!P```!,``````````````)"^````````!P```!0`
M`````````````)B^````````!P```!4``````````````*"^````````!P``
M`!8``````````````*B^````````!P```!<``````````````+"^````````
M!P```!@``````````````+B^````````!P```!D``````````````,"^````
M````!P```!H``````````````,B^````````!P```!L``````````````-"^
M````````!P```!P``````````````-B^````````!P```!X`````````````
M`."^````````!P```!\``````````````.B^````````!P```"$`````````
M`````/"^````````!P```"(``````````````/B^````````!P```",`````
M``````````"_````````!P```"0```````````````B_````````!P```"4`
M`````````````!"_````````!P```"8``````````````!B_````````!P``
M`"<``````````````""_````````!P```"D``````````````"B_````````
M!P```"H``````````````#"_````````!P```"L``````````````#B_````
M````!P```"P``````````````$"_````````!P```"T``````````````$B_
M````````!P```"X``````````````%"_````````!P```"\`````````````
M`%B_````````!P```#```````````````&"_````````!P```#$`````````
M`````&B_````````!P```#,``````````````'"_````````!P```#0`````
M`````````'B_````````!P```#4``````````````("_````````!P```#8`
M`````````````(B_````````!P```#<``````````````)"_````````!P``
M`#@``````````````)B_````````!P```#D``````````````*"_````````
M!P```#H``````````````*B_````````!P```#P``````````````+"_````
M````!P```#T``````````````+B_````````!P```#X`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%S9\``$B%P'0"_]!(@\0(PP```````````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)2*<``!H-@```.F`_/___R52G```9I``````````
M`$%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*```
M`$B)1"0H,<#H%_[__TB+-?";``!(BSWQFP``2(GRZ/$Y``"`/2J<````=2_H
M4_W__TB)!82L``!(B<=(A<`/A)`!``#HF_S__XL]]9L``.C@_?__QH#I"0``
M`(L]XYL``.C._?__BSW8FP``@(@Z!````NB\_?__@(@Z!````8M$)!R->`1$
MC6`#2&/_2,'G`^@N_?__2(M,)!"+="0<28G!2(D%"ZP``$B+`4F)`4B-!3H]
M``!)B4$(2(L%>YL``$F)01!(C04G/0``28E!&(/^`0^.\0```$B#P0B#Q@.X
M!`````\?@`````!(BSE(8]"#P`%(@\$(28D\T3G&=>M(8_9(P>8#2(L]K:L`
M`$2)XD4QP$R)R4G'!#$`````2(TU;0@``.B(_?__08G$A<!T4TB+/8*K``!(
MC6PD).@@_/__,<!(B>Y(C3UW.P``Z'\!``!(A<!T/4B+/5NK``#HGOO__^@9
M_?__2(M$)"AD2"L$)2@```!U8TB#Q#A$B>!=05S#2(L]+ZL``.BR_?__08G$
MZYQ(BST.JP``2(7_=`?HG!P``.NP2(T]S3H``$B)[N@;`0``2(D%[*H``$B)
MQTB%P'22Z]F^(````.DT____OP$```#HAOW__^A1^___D#'M28G17DB)XDB#
MY/!05$R-!0HX``!(C0VC-P``2(T]S/W___\5YID``/0/'T0``$B-/2F:``!(
MC04BF@``2#GX=!5(BP6VF0``2(7`=`G_X`\?@`````###Q^``````$B-/?F9
M``!(C37RF0``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!:69``!(A<!T"/_@
M9@\?1```PP\?@`````"`/0&:````=2]52(,]AID```!(B>5T#$B+/8J9``#H
M'?W__^AH____Q@79F0```5W##Q^``````,,/'X``````Z7O___]F+@\?A```
M````D$%7059!54%455-(@^P(2(7_#X2Q````3(LM<ID``$V%[0^$H0````^V
M!TF)_TB)]83`=`0\/75813'V38ME`$V%Y'0R36/V3(GK9@\?1```3(GR3(G^
M3(GGZ%+Y__^%P'4'0X`\-#UT1TR+8PA(@\,(387D==I(@\0(3(G@6UU!7$%=
M05Y!7\,/'X0``````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY(/'X``````
M3"GK3XUD-`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!!5D%505154TB![*``
M``!D2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@K
M!"4H````#X4I`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#HR_C__TF)
MQ$B%P'3"28GE3(GGZ.CZ__](A<`/A*\```"`>!,N2(U8$W4-@'L!`'3?#Q^`
M`````(!X$RX/A*8```!(B>_HUOC__TB)WTF)QNC+^/__08U\!@)(8__HWOG_
M_TF)V4F)Z+X!````28G&2(G',<!(Q\+_____2(T-H3<``.@H^___OP$```!,
MB>I,B?;H*/C__TR)]X/X_W00BT0D&"4`\```/0!```!T6.B[]___3(GWZ)/W
M__],B>?H._K__TB%P`^%4____V:03(GGZ,CX__](B>_H,/C__^GJ_O__#Q\`
M@'L!+@^%4/___X![`@`/A!3____I0?___P\?@`````#HD_[__^NFZ!SX__]F
M9BX/'X0``````)!52(G^2(G]OP$```!(@>R@````9$B+!"4H````2(F$))@`
M```QP$B)XN@"^O__A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(`
M``!(B>_HE_G__X7`#Y3`#[;`ZP</'T0``#'`2(N,))@```!D2"L,)2@```!U
M"4B!Q*````!=P^B%]___#Q]$``!52(G]Z&?W__](C50%_T@YU7(6Z9$````/
M'X0``````$B#Z@%(.=5T)8`Z+W3R2#G5<W9(@^H!2#G5=!(/'T``@#HO="A(
M@^H!2#G5=?*`?0`O=%Q(C3TA-@``7>E_^?__#Q^``````(`Z+W4)2(/J`4@Y
MU7+R2"GJ,<!(C4H"2('Y`!```'<?2(/"`;D`$```2(GN2(T]598``.A0^/__
M2(T%298``%W#2#G5=;_KGDB-/<,U``!=Z2/Y__\/'P!!5[K_#P``059!54%4
M28GT54B)_4B-/:,U``!(@>P0$```9$B+!"4H````2(F$)`@0```QP$F)Y4R)
M[NCP]?__A<!^=(U0_T2+/8*5``!,8_)"@#PT`'58A=)T8TR)\KXO````3(GO
MZ/3V__](A<!T3D2)_^A']___3(GQ3(GJ2(GN2(G'Z#;X__](BX0D"!```&1(
M*P0E*````'4Z2('$$!```%U!7$%=05Y!7\-FD$QC\.NG#Q\`1(L]$94``$2)
M_^CY]O__3(GB2(GN2(G'Z"OV___KL^CD]?__#Q]``$%7059!54%454B)]5-(
MB?M(@^P89$B+!"4H````2(E$)`@QP#'`@#X]#Y3`2`'%2(GOZ)GU__](C70D
M!$B)WTF)Q#'`Z#?[__](A<`/A`8!``!(B<=)B<7H<_7__TDYQ`^&T@```$QC
M="0$2<'F`P^V`X3`#X2>`0``/#T/A)8!``!(B=@/'P`/ME`!2(/``832=`6`
M^CUU[T@IV$B82HU\(`),`S5FE```Z$'V__])B09(A<!T6DB+!5*4``!(8U0D
M!$B-2P%(BQ30#[8#B`*$P'0A/#UU#.L;9@\?1```A,!T$0^V`4B#P@%(@\$!
MB`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(@\`!A,EU[TB+1"0(9$@K!"4H
M````#X4'`0``2(/$&%M=05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!B%0%
M`$B#P`&$TG7NZ[T/'T``3(L]L9,``$F#/P`/A+8```!,B?A%,>V02(/`"$2)
MZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP6_HP``A<!U6\<%L:,```$```!(B??H
M2?7__TB%P`^$8?___TUC]4R)_DB)QTG!Y@-,B?+HV_7__TB)!423``!(B<%!
MC44!2)A(QP3!`````$2);"0$Z8C^__]F#Q^$``````!,B?_HB/7__TB)!1&3
M``!(B<%(A<`/A`;___]-8_5)P>8#Z[L/'T``,<#I?_[__[X0````13'MZ5__
M___HK_/__V9F+@\?A```````#Q]``$B#[`B+/::2``#HD?3__XL]FY(``.B&
M]/__2(L5-Y(``$B-#;!O``!(C35^,@``2(G'Z*GT__^+/7.2``#H7O3__TR-
M!?`S``!%,<E(C16]$0``2(G'3(G!2(TU:3(``$B#Q`CIQ_3__P\?@`````!(
M@^P(BSTVD@``Z"'T__](BQ72D0``2(/$"$B-#4=O``!(B<=(C342,@``Z4#T
M__]!5%532('L("```&1(BP0E*````$B)A"08(```,<!(B>5,C:0D$!```.A2
M\O__3(T-U#$``+H!$```2(GO08G`2(T-]S$``+X!````,<#H+?7__[H`$```
M3(GF2(GOZ`WR__]%,<"%P'@NC7@!2(G#2&/_Z)CS__])B<!(A<!T&$ACVTR)
MYDB)QTB)VNA/\___Q@08`$F)P$B+A"08(```9$@K!"4H````=0](@<0@(```
M3(G`6UU!7,/H0?+__Y#I.____V9F+@\?A```````05=!5D%528GU05152(G]
M2(T]9#$``%-(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z)7W__^^
M+P```$B)[TB)P^@%\O__2(7`=$`QP$B)[DB-/2<Q``#H[_O__TB)Z$B+G"2H
M$```9$@K'"4H````#X6"`0``2('$N!```%M=05Q!74%>05_##Q\`2(GOZ(CQ
M__](C37Q,```3(GO08G$Z';S__])B<9(A<!TGD&`/@!,C2UM,```#X3>````
M#Q]$``!(A=MT$TR)]DB)W^@8\O__A<`/A)T```!,B??H./'__XU0_XG!2&/"
M3`'P@#@O=1L/'X0``````(G1@^H!Q@``2&/"3`'P@#@O=.U"C40A`3W_#P``
M#X\M____38GPN@`0``"^`0```#'`3(V\)*````!(@^P(2(T-/S$``%5,C0W?
M+P``3(G_Z%OS__](C50D($R)_K\!````Z%GP__]:687`=1"+1"0H)0#P```]
M`(```'132(TU##```#'_Z)7R__])B<9(A<`/A+G^__]!@#X`#X4G____2(7;
M=`6`.RYT%4V)[KD!````Z5O___\/'X0``````(![`0!TM^OC#Q^$``````"^
M`0```$R)_^@S\O__A<!UG$R)_DB-/9@O``#H8/K__TR)_^B8\O__Z6?^___H
M+O#__V9F+@\?A```````#Q\`#[8'28GXA,!T%V8/'T0``$B#QP$\+P^V!TP/
M1,>$P'7O3(G`PV9F+@\?A```````2(7_=`N`/P!T!NEA^/__D$B-/=,N``#I
M-/+__P\?0`!54TB-'2DO``!(@^Q(9@]O!0ML``!D2(L$)2@```!(B40D.#'`
M,<!(C6PD#`\11"009@]O!?=K``!FB40D,`\11"0@#Q]$```QP$B)[DB)W^@;
M]?__2(7`=#Y(8U0D#$B+!9J.``!(C0302(M0"$B)$$B%TG329BX/'X0`````
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'9PN``"0,<!(B>Y(B=_HP_3_
M_TB%P'0V2&-4)`Q(BP5"C@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(T=5"X``)`QP$B)[DB)W^AS]/__2(7`=#9(8U0D
M#$B+!?*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$``!(C1T-+@``D#'`2(GN2(G?Z"/T__](A<!T-DAC5"0,2(L%HHT``$B-
M!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'<0M
M``"0,<!(B>Y(B=_HT_/__TB%P'0V2&-4)`Q(BP52C0``2(T$T$B+4`A(B1!(
MA=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=A"T``)`QP$B)[DB)
MW^B#\___2(7`=#9(8U0D#$B+!0*-``!(C0302(M0"$B)$$B%TG329I!(BU`0
M2(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1WK+```D#'`2(GN2(G?Z#/S__](A<!T
M-DAC5"0,2(L%LHP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72
M=?#KOF8/'T0``$B-'?`L``"0,<!(B>Y(B=_HX_+__TB%P'0V2&-4)`Q(BP5B
MC```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```
M2(T=JBP``)`QP$B)[DB)W^B3\O__2(7`=#9(8U0D#$B+!1*,``!(C0302(M0
M"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1UD+```D#'`
M2(GN2(G?Z$/R__](A<!T-DAC5"0,2(L%PHL``$B-!-!(BU`(2(D02(72=-)F
MD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-';0K``"0,<!(B>Y(B=_H\_'_
M_TB%P'0V2&-4)`Q(BP5RBP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(GN2(T]RRL``.BI\?__2(G&2(7`=`Y(C3VC*P``
M,<#H$_;__TB)[DB-/;<K```QP.B"\?__2(G&2(7`=`Y(C3VS*P``,<#H[/7_
M_TB)[DB-/:TK```QP.A;\?__2(G&2(7`=#I(C3WV*@``,<#HQ?7__S'`2(TU
M5BP``$B-/1@K``#HL/7__TB+1"0X9$@K!"4H````=5%(@\1(6UW#2(GN2(T]
M:BL``#'`Z`CQ__](B<9(A<!T$$B-/?@J```QP.AR]?__ZZM(N%!!4E]#3$5!
M2#E$)"%UFF:!?"0I3CUUD4B-="0KZ\_H*NO__V8N#Q^$``````!(@^P89$B+
M!"4H````2(E$)`B+!0B*``"#^/]T&TB+?"0(9$@K/"4H````=4)(@\08PV8/
M'T0``$B-="0$2(T]>RH``#'`Z'7P__](B<(QP$B%TG02#[82@/HP#Y7!,<"$
MT@^5P"'(B06SB0``ZZ[HK.K__V9F+@\?A```````D$B#[`CHI^K__XG'Z%#J
M__](A<!T`TB+`$B#Q`C##Q\`05152(G]2(T]BBH``%-(@^P09$B+!"4H````
M2(E$)`@QP$B-="0$Z/3O__](A<!T"(`X`$B)PW4W2(M$)`AD2"L$)2@````/
MA;D```!(B>Y(@\002(T]/"H``#'`6UU!7.DZ]/__9BX/'X0``````$B)[DB)
MQ^AU[/__2(7`="!(BT0D"&1(*P0E*````'5V2(/$$%M=05S##Q^``````$B)
M[^C(Z?__2(G?28G$Z+WI__])C7P$`NC3ZO__2(/L"$F)Z+X!````4TC'PO__
M__](B<=)B<1,C0T"*0``2(T-[RD``#'`Z!3L__]86DB+1"0(9$@K!"4H````
M=0A,B>;I2O___^AUZ?__#Q]$``!!5T%6055)B?U(C3VJ*```05154TB![(B!
M``!D2(L$)2@```!(B80D>($``$B-!7`I``!,C60D'$C'1"0P`````$C'A"2(
M`````````$R)YDC'1"10`````$B)1"0@2(T%!2@``$B)1"0H2(T%V"@``$B)
M1"1H2(T%*RD``$B)1"1P2(T%W2@``$B)1"1X2(T%&RD``$B)A"2`````2(T%
M$"D``$B)1"1(,<#H8.[__TB%P'0,@#@`2(G%#X6/!```Z+KH__^)Q^ACZ/__
M2(7`#X3:`P``2(LH2(7M#X3.`P``2(GOZ';H__](C7P``>B,Z?__1`^V10!(
MB<-%A,!T.DF)WTR--;(H```/'T0``$R)_TR)\4C'PO____\QP+X!````2(/%
M`4F#QP+HO^K__T0/MD4`183`==5,C70D8$B-/0DH``#K&`\?@`````!)BWX(
M28/&"$B%_P^$+P$``$R)YC'`Z*7M__](B<5(A<!TW8`X`'382(G'Z.#O__^%
MP'3,2(GOZ$3J__])B<=(A<`/A/@````/'X0``````$R)_^BXY___2(G?2(G%
MZ*WG__]$C;0%!`0``$UC]DR)]^BZZ/__4TV)^$R-#9LF``!(B<5(C07P)P``
MO@$```!(Q\+_____4$B-#=,G``!(B>\QP.CWZ?__2(GOOL`!``#HRN;__U]!
M6(/X_W42Z(WF__]$BPA!@_D1#X4$`P``2(V4))````!(B>Z_`0```.A;Z?__
MB<.%P`^$L0```$F+30!(BSUVA@``28GH,<!(C14B*```O@$```!%,?;H7>G_
M_TB+A"1X@0``9$@K!"4H````#X56!0``2('$B($``$R)\%M=05Q!74%>05_#
MD$B+;"0@13'VZQ-F#Q]$``!)8\9(BVS$($B%[70[@'T``'0U2(GO08/&`>BA
M[O__A<!TW4B)[^@%Z?__28G'2(7`#X7)_O__26/&2(MLQ"!(A>UUR0\?0`!%
M,?_IL/[__XN$)*@````E`/```#T`0```#X4X____1(N\)*P```#H;.;__T$Y
MQP^%(O___XN$)*@````E_P$``#W``0``#X4+____3(GWZ$3G__](C3U/)@``
M3(GF28G&,<#HP.O__TB)QTB%P`^$-`(``.AOZ/__28M]`$B)QNC3\___28G'
M2(7`#X07`@``3(G_Z-_E__^#^`-^.DACT+D%````2(T].R8``$F-=!?\\Z8/
ME\*`V@"$TG4:@_@$#X1U`P``@^@%2)A!@#P'+P^$90,``)"+!:J$``"#^/\/
MA!D#``"%P`^$S`$``$B--4PF``!(C3TJ)0``,<#HI.___TR-)18F``!,C2UR
M)```Z/'D__]!5$F)Z+X!````4$C'PO____],B?<QP$R-#4\D``!(C0W%)0``
MZ,?G__]86NM$#Q\`Z&OD__^#.!%U2>BQY/__@\,!2(/L"$V)Z4%428GH2(T-
MHB4``$R)]U-(Q\+_____O@$```!0,<#H@^?__TB#Q""^P`$``$R)]^A2Y/__
M@_C_=*U(B>_H!>3__TR)]DB-/24D```QP.CT[O__3(GWZ$SZ___INOW__P\?
M@``````QVTB-/=XD``#K$@\?1```2&/#2(M\Q$!(A?]T.$R)YC'`@\,!Z#;J
M__](A<!TX8`X`'3<2(G'Z.3F__](B<5(A<`/A>K[__](8\-(BWS$0$B%_W7(
MOPT```!(C2V+)```Z&KE__]!N%,```!(B</IW?O__TF+30!(BSV1@P``28GH
M,<!(C17])```O@$```!%,?;H>.;__^D6_?__#Q\`2(G'Z)CY__](BX0D>($`
M`&1(*P0E*`````^%80(``$B!Q(B!``!(B>];74%<05U!7D%?Z4CF__\/'X0`
M`````$V+?0#IX/W__\<%S8(````````Q]DR)_S'`Z''E__]!B<2%P`^$'?[_
M_[H"````2,?&[O___XG'Z./E__](C9PD<`$``+H&````1(GG2(G>Z#OD__^`
MO"1P`0```'4.@+PD<0$``$,/A&D!```QTC'V1(GGZ*?E__\QP.C0&P``28G%
MZQ`/'P")PDB)WDR)[^@;'```N@"```!(B=Y$B>?HZ^/__X7`?]]$B>=,C;PD
M(`$``$R-)7(C``#H@./__TR)[DR)_TR-K"1H`0``Z'T=``!(C80D0`$``$B)
M1"0(2(G##Q]$``!%#[8'2(G?3(GAO@$```!(Q\+_____,<!(@\,"28/'`>A3
MY?__23G===9(C05@(P``QH0D:`$```!0_W0D$$B-#1TC``!)B>A,B?<QP+X!
M````3(T-FR$``$C'PO_____H$^7__UE>Z9_]__\/'T``,<!,B>9(C3T;(@``
MZ!?H__](A<`/A)?^__\/M@"$P`^$C/[__SPP#X2$_O__QP51@0```0```.FS
M_/__38MM"$V%[0^$C_S__TR)[^@GXO__2(/X`P^&??S__TF-=`7\N04```!(
MC3V!(@``\Z8/E\`<`(3`30]$_>E:_/__@+PD<@$``$$/A8G^__^`O"1S`0``
M0P^%>_[__X"\)'0!``!(#X5M_O__@+PD=0$``$4/A5_^__^Z`@```$C'QL;_
M__]$B>?H_N/__[HI````2(G>1(GGZ%[B__](C05`(@``4%/IYO[__^B;X?__
M9F8N#Q^$``````!!54%454B#[!"+/9&```!D2(L$)2@```!(B40D"#'`Z&SB
M__^+/7:```!(B<7H7N+__P^VE;@```!(C6PD!$B-/<X@``!(B>Z(D+D````Q
MP.C;YO__2(7`=`F`.#$/A+4!```QP.A6\?__BSTP@```Z!OB__^Y`P```+H!
M````2(TUHB$``$B)Q^C2X?__28G$2(7`=#A(BT`0BST`@```3(LHZ.CA__](
MC15[(0``2(G'3(GNZ!;A__])BT0D$$R+($'V1"0.0`^%D@$``(L]S'\``.BW
MX?__N0,```"Z`0```$B--44A``!(B<?H;N'__TF)Q$B%P'0^2(GN2(T]WQ\`
M`#'`Z"7F__])B<5(A<`/A!D!``!)BT0D$(L]?G\``$R+(.AFX?__3(GJ2(G'
M3(GFZ)C@__^+/6)_``#H3>'__[H!````2(TUXB```$B)Q^A9X?__BSU#?P``
M28G$Z"OA__],B>9(C177(```2(G'Z%G@__^+/2-_``#H#N'__TB)[DB-/4X?
M``#&@+D`````,<#HEN7__TB)!6>/``!)B<1(A<!T/[[``0``3(GGZ#K?__^-
M4`&#^@%V"8/X$0^%M````$B+1"0(9$@K!"4H````#X6]````2(/$$%U!7$%=
MPP\?`$B+/2&/``#H+/;__TB)!0V/``!)B<1(A<!UIDB-/>8@```QP.BOX/__
M#Q^``````(!X`0`/A$C^___I//[__V8/'X0``````$B+!=F.``"+/6-^``!,
MBRA)BT0D$$R+(.A#X/__3(GN3(GGZ'CH___IV_[__P\?`(L].GX``.@EX/__
M3(GF2(G'Z'K@___I4_[__XG!2(L%C(X``$R)XDB-/8H@``!(BS`QP.@HX/__
MZ//>__\/'P!!5%5(B?U32(/L$&1(BP0E*````$B)1"0(,<!(A?\/A+P```"`
M/P`/A+,```#H/N?__P^V$$B)PX32=!8/'T``2(/``8#Z+P^V$$@/1-B$TG7N
MBP68?0``2(7M00^5Q(/X_P^$D````(7`#Y7`02'$183D=2-(BT0D"&1(*P0E
M*`````^%L````$B#Q!!;74%<PV8/'T0``(!]``!TU[D$````2(T]H1X``$B)
MWO.F#Y?`'`"$P'6]2(M$)`AD2"L$)2@```!U<4B#Q!!(B>];74%<Z8CD__\/
M'X0``````$B-/0,=``#H9.#__^E!____#Q^``````#'`2(UT)`1(C3V)'0``
MZ(7C__](A<!T"P^V`(3`=`0\,'4/QP7+?````````.E+____QP6\?````0``
M`.DW____Z++=__]FD$%73(U/.$%6055!5%532('LF`(``&1(BP0E*````$B)
MA"2(`@``,<!(B>),C90D@````$F)T&8N#Q^$``````!!BP%)BS%)@\`028/!
M"`_(B<!(B?%)B4#P2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(B<Y(P>$(2,'F
M&('A``#_`(GV2`GP2`G(28E`^$TYT'6N2(VR``(```\?@`````!(BT)H2#-"
M0$B#P@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y\G753(L/3(M?$$B+
M=R!(BU\83(G(3(G*2(MO"$C!ZAM(P>`%2`G0`P0DC90PF7F"6DR)V$B+="0(
M2#'82"'H2(VT,YEY@EI(,=A$C10"2(GJ2(GH2,'H`DC!XAY-B=!("<),B=A)
MP>@;B=%(,<A,(<A,,=A(`?!,B=9(P>8%3`G&1(TT,$R)SDR)R$C!YAY(P>@"
M38GP2`GP2(MT)!!)P>@;2#'"08G%3"'228VT,YEY@EI(,<I(`?),B?9(P>8%
M3`G&1(T$,DR)UDG!Z@)(BU0D&$C!YAY,"=9(C901F7F"6DR)P4@Q\$&)]$PA
M\$PQZ$C!Z1M(`=!,B<)(P>(%2`G*3(GQ2<'N`DC!X1Y$C1002(GP2(M4)"!,
M"?%,B=9(,<A)C905F7F"6DC![AM!B<Y,(<!,,>!(`=!,B=)(P>(%2`GR1(TL
M$$R)PDG!Z`)(BT0D*$C!XAY,B>Y,"<))C80$F7F"6DC![AM(,=%!B=!,(=%,
M,?%(`<%,B>A(P>`%2`GP1(TD`4R)T$G!Z@)(BTPD,$C!X!Y,B>9,"=!)C8P.
MF7F"6D@QPD&)PDPAZDPQPD@!RDR)X4C!X05(P>X;2`GQ3(GN2<'M`DC!YAY$
MC30*2(M4)#A,">Y,B?%(,?!)C900F7F"6DC!Z1M!B?5,(>!,,=!(`=!,B?)(
MP>(%2`G*3(GA2<'L`DC!X1Y$C0002(GP2(M4)$!,">%,B<9(,<A)C902F7F"
M6DC![AM!B<Q,(?!,,>A(`=!,B<)(P>(%2`GR1(T4$$R)\DG![@)(BT0D2$C!
MXAY,B=9,"?))C80%F7F"6DC![AM(,=%!B=9,(<%,,>%(`<%,B=!(P>`%2`GP
M1(TL`4R)P$G!Z`)(BTPD4$C!X!Y,B>Y,"<!)C8P,F7F"6DC![AM(,<)!B<!,
M(=),,?)(`<I,B>E(P>$%2`GQ3(G62<'J`DC!YAY$C20*2(M4)%A,"=9,B>%(
M,?!)C906F7F"6DC!Z1M!B?),(>A,,<!(`=!,B>)(P>(%2`G*3(GI2<'M`DC!
MX1Y$C3002(GP2(M4)&!,">E,B?9(,<A)C900F7F"6DC![AM!B<U,(>!,,=!(
M`=!,B?)(P>(%2`GR1(T$$$R)XDB+1"1H2,'B'DG![`),B<9,">))C80"F7F"
M6DC![AM(,=%!B=1,(?%,,>E(`<%,B<!(P>`%2`GP1(T4`4R)\$G![@)(BTPD
M<$C!X!Y,B=9,"?!)C8P-F7F"6DC![AM(,<)!B<9,(<),,>)(`<I,B=%(P>$%
M2`GQ3(G&2<'H`DC!YAY$C2P*2(M4)'A,"<9,B>E(,?!)C904F7F"6DC!Z1M!
MB?!,(=!,,?!(`=!,B>I(P>(%2`G*3(G12<'J`DC!X1Y$C2002(GP2(N4)(``
M``!,"=%,B>9(,<A)C906F7F"6DC![AM!B<I,(>A,,<!(`=!,B>)(P>(%2`GR
M1(TT$$R)ZDG![0)(BX0DB````$C!XAY,B?9,">I)C80`F7F"6DC![AM(,=%!
MB=5,(>%,,=%(`<%,B?!(P>`%2`GP1(T$`4R)X$G![`)(BXPDD````$C!X!Y,
M">!)C8P*F7F"6DV)PD@QPDG!ZAN)QDPA\DPQZD@!RDR)P4C!X05,"=%-B?))
MP>X"2<'B'HG)30GR2`'*2(N,))@```!,,=!!B=1,(<!)C8P-F7F"6DV)Y4@Q
M\$G![1M(`<A,B>%(P>$%3`GIB<E(`<A,B<%)P>@"2,'A'D&)Q4P)P4V)T$6)
MTDP#E"2H````23'(1#'"3(N$)*````!.C80&H>O9;DR)[DD!T$R)ZDC![AM(
MP>(%2`GRB=))`=!,B>))P>P"2,'B'D2)QDP)XDF)S(G)2`.,)+````!),=1$
M,>!)B?1-C90"H>O9;DB)\$G![!M(P>`%3`G@B<!)`<),B>A)P>T"2,'@'D6)
MU$P)Z$F)U8G223'%13'H38GE2`.4)+@```!.C80!H>O9;DR)X4G![1M(P>$%
M3`GIB<E,`<%)B?!(P>X"2<'@'D&)S4D)\$B)QHG`2`.$),````!,,<9!,?)*
MC;02H>O9;DR)ZDV)ZDG!ZAM(P>(%3`G2B=)(`?),B>9)P>P"2,'F'D&)TDP)
MYDV)Q$6)P$P#A"3(````23'T1#'A38G42(V,"*'KV6Y,B=!)P>P;2,'@!4P)
MX(G`2`'(3(GI2<'M`DC!X1Y!B<1,">E)B?6)]DDQS40QZDV)Y4V-A!"AZ]EN
M3(GB2,'B!4G![1M(`[0DT````$P)ZHG220'03(G22<'J`DC!XAY%B<5,"=))
MB<J)R4@#C"38````23'21#'038GJ2(VT!J'KV6Y,B>A)P>H;2,'@!4P)T(G`
M2`'&3(G@2<'L`DC!X!Y!B?),">!)B=2)TD@#E"3@````23'$13'@38G43HV$
M`:'KV6Y,B=%)P>P;2,'A!4P)X8G)3`'!38GH2<'M`DG!X!Y!B<Q-">A)B<6)
MP$TQQ40Q[DV)Y4B-M#*AZ]EN3(GB2<'M&TC!X@5,">J)TD@!\DR)UDG!Z@)(
M`X0DZ````$C!YAY!B=5,"=9-B<)%B<!,`X0D\````$DQ\D0QT4V)ZDB-C`BA
MZ]EN3(GH2<'J&TC!X`5,"=")P$@!R$R)X4G![`)(P>$>08G"3`GA28GTB?9(
M`[0D^````$DQS$0QXDV)U$V-A!"AZ]EN3(G22<'L&TC!X@5,">*)TDD!T$R)
MZDG![0)(P>(>18G$3`GJ28G-B<E),=5$,>A-B>5(C;0&H>O9;DR)X$G![1M(
MP>`%3`GHB<!(`<9,B=!(P>`>2<'J`D&)]4@#C"0``0``3`G028G2B=)(`Y0D
M"`$``$DQPD4QT$V)ZDZ-A`&AZ]EN3(GI2<'J&TC!X05,"=&)R4P!P4V)X$G!
M[`))P>`>08G*30G@28G$B<!(`X0D$`$``$TQQ$0QYDV)U$B-M#*AZ]EN3(G2
M2<'L&TC!X@5,">*)TD@!\DR)[DG![0)(P>8>08G43`GN38G%18G`23'U1#'I
M38GE2(V,"*'KV6Y,B>!)P>T;2,'@!4P)Z(G`2`'(3(G12<'J`DC!X1Y!B<5,
M"=%)B?),`X0D&`$``(GV23'*2`.T)"`!``!$,=)-C;00H>O9;DR)ZDV)Z$G!
MZ!M(P>(%3`G"28G(B<E(`XPD*`$``(G220'63(GB2<'L`DC!XAY%B?),">))
M,=!$,<!,C:0&H>O9;DR)T$R)UDC![AM(P>`%2`GP2(G6B=)(`Y0D,`$``(G`
M20'$3(GH2<'M`DC!X!Y%B>!,">A(,<9!,?9,B<9.C:PQH>O9;DR)P4C![AM(
MP>$%2`GQB<E)`<U,B=%)P>H"2,'A'D2)[DP)T4F)PHG`23'*13'42`.$)#@!
M``!.C90BH>O9;DB)\DF)]$G![!M(P>(%3`GB38G$2<'H`DG!Y!Y!`=)-"<1)
MB<B)R4TQX$2)XD4QQ4Z-A"BAZ]EN3(G038G52<'M&TC!X`5,">A,BZPD0`$`
M`$6--`!)B?!(P>X"3(G@2<'@'DD)\$2)QDP)P$PAT$DA]$D)Q+C<O!N/20'%
M3`'I38GU3`'A38GT2<'M&TG!Y`5-">Q!`<Q,B=%)P>H"2,'A'DP)T4D)R$F)
MS4&)RDTA\$DA]4T)Z$R+K"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,
M">I%C2P03(GR2<'N`DC!XAY,"?))B<Y!B=!)"=9-(>9,(<%,"?%,B[0D4`$`
M`$D!QDP!]DV)[D@!\4R)[DG![AM(P>8%3`GV1(TT,4R)YDG![`)(P>8>3`GF
M2`GR28GTB?%-(<1,(>I,">),BZ0D6`$``$D!Q$T!XDV)]$P!TDV)\DG!X@5)
MP>P;30GB1HTD$DV)ZDG![0))P>(>30GJ28GU1(G230G532'U2"'63`GN3(NL
M)&`!``!)`<5-`>A-B>5,`<9-B>!)P>T;2<'@!4T)Z$:-+`9-B?!)P>X"2<'@
M'DT)\$T)PDV)QD2)QDDAUDTAXDT)\DR+M"1H`0``20'&3`'Q38GN20'*3(GI
M2<'N&TC!X05,"?%%C30*3(GA2<'L`DC!X1Y,">%-B<1)"<Q!B<I-(>Q-(=!-
M">!,BZ0D<`$``$D!Q$P!XDV)]$D!T$R)\DG![!M(P>(%3`GB18TD$$R)ZDG!
M[0)(P>(>3`GJ2`G128G508G032'53"'Q3`GI3(NL)'@!``!)`<5,`>Y-B>5(
M`?%,B>9)P>T;2,'F!4P)[D2-+#%,B?9)P>X"2,'F'DP)]DF)UHGQ20GV32'F
M2"'*3`GR3(NT)(`!``!)`<9-`?)-B>Y,`=)-B>I)P>X;2<'B!4T)\D:--!)-
MB>))P>P"2<'B'DT)XDP)UDV)U$2)TDDAS$PA[DP)YDR+I"2(`0``20'$30'@
M38GT3`'&38GP2<'L&TG!X`5-">!&C20&38GH2<'M`DG!X!Y-">A-B=5$B<9-
M"<5-(?5)(?)-">I,BZPDD`$``$D!Q4P!Z4V)Y4D!RDR)X4G![1M(P>$%3`GI
M18TL"DR)\4G![@)(P>$>3`GQ20G(28G.08G*22'V32'@30GP3(NT))@!``!)
M`<9,`?)-B>Y)`=!,B>I)P>X;2,'B!4P)\D6--!!,B>))P>P"2,'B'DP)XDF)
MS$&)T$D)U$TA[$PAP4P)X4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L&TC!
MY@5,">9$C20Q3(GN2<'M`DC!YAY,">Y("?))B?6)\4TAQ4PA\DP)ZDR+K"2H
M`0``20'%30'J38GE3`'238GB2<'M&TG!X@5-">I&C2P238GR2<'N`DG!XAY-
M"?))B?9$B=)-"=9-(>9((=9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)Z$G!
M[AM)P>`%30GP1HTT!DV)X$G![`))P>`>30G@30G"38G$1(G&22'432'J30GB
M3(ND)+@!``!)`<1,`>%-B?1)`<I,B?%)P>P;2,'A!4P)X46-)`I,B>E(P>$>
M2<'M`DP)Z4V)Q4&)RDD)S4TA]4TAT$T)Z$R+K"3``0``20'%3`'J38GE20'0
M3(GB2<'M&TC!X@5,">I%C2P03(GR2<'N`DC!XAY,"?)("=%)B=!!B==-(=!,
M(>%,"<%,BX0DR`$``$D!P$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$,4R)
MYDG![`)(B=%(P>8>3`GF08GT2`GQ3"'I3"'B2`G*2(N,)-`!``!(`<%(`X0D
MV`$``$D!RDR)P4D!QTP!TDV)PDC!X05)P>H;3`G1B<E(`<I,B>E)P>T"2,'A
M'D&)TDP)Z4R)T$@)SDF)S4C!X`5!B<Y-(>5,(<9,">Y-B=5)P>T;3`'^3`GH
MB<!(`<9,B<!)P>@"2,'@'D&)]4D)P+C6P6+*3#'!,<I(BXPDX`$``$@!P4P!
MX4V)[$@!T4R)ZDG![!M(P>(%3`GBB=)(`=%,B=))P>H"2,'B'D&)S$D)TDR)
MPD6)P$PQTC'62(N4).@!``!(`<))`=9,B>),`?9-B>9(P>(%2<'N&TP)\HG2
M3(TT%DR)ZDG![0),B=9(P>(>18GW18G220G52(N4)/`!``!,,>Y(`<(Q\4R)
M_DP!PDC![AM(`=%,B?I(P>(%2`GR2(NT)/@!``")TD@!T4R)XD@!QDG![`)(
MP>(>3`'638GJ08G(3`GB38G$18GM23'213'63HT4-DR)QDC!Y@5)P>P;3`GF
MB?9)`?),B?Y)P>\"2,'F'D6)U$D)]TB+M"0``@``2`'&3`'N28G5B=)-,?U$
M,>E,C2P.3(GA3(GF2,'N&TC!X05("?%,B<9)P>@"B<E(P>8>20'-2(N,)`@"
M``!,"<9-B?A),?!%B>Y%B?](`<%%,<)(`<I,B?%.C0023(GR2,'I&TC!X@5(
M"<I(B?&)]HG220'03(GB2<'L`DC!XAY%B<))"=1(BY0D$`(``$PQX4@!PD$Q
MS4R)T4P!^DD!U4R)TDC!Z1M(P>(%2`G*3(GQ2<'N`HG22,'A'DD!U4B+E"08
M`@``3`GQ18GO2`'"2`'R3(GF18GD2#'.03'P3(G^20'03(GZ2,'N&TC!X@5(
M"?*)TDD!T$R)TDG!Z@)(P>(>18G&20G22(N4)"`"``!,B?9(P>X;2`'"3`'B
M28G,B<E-,=1%,>5.C20J3(GR2,'B!4@)\DB+M"0H`@``B=))`=1,B?I(`<9)
MP>\"2,'B'D6)Y4P)^D@!\4R)UD6)TD@QUD$Q\$R)[DD!R$R)Z4C![AM(P>$%
M2`GQB<E)`<A,B?%)P>X"2,'A'D6)QTD)SDB+C"0P`@``3(G^2,'N&T@!P4P!
MT4F)THG233'R13'43HT4(4R)^4C!X05("?%,B>Y)P>T"B<E(P>8>20'*2(N,
M)#@"``!,">Y%B=1(`<%(`<I,B?%%B?9(,?%!,<A,B>%)`=!,B>)(P>D;2,'B
M!4@)RDB)\8GVB=))`=!,B?I(P>(>2<'O`D6)Q4D)UTB+E"1``@``3#'Y2`'"
M03'*3(GI3`'R2,'I&TD!TDR)ZDC!X@5("<I,B>%)P>P"B=)(P>$>20'22(N4
M)$@"``!,">%%B?Q%B=9(`<)(`?),B?Y(,<Y!,?!*C30"3(GR38GP2<'H&TC!
MX@5,"<*)TD@!UDR)ZDG![0)(P>(>08GP20G52(N4)%`"``!(`<),`>))B<R)
MR4TQ[$4QXDZ-)!),B<)-B<))P>H;2,'B!4P)THG220'43(GR2<'N`DC!XAY%
MB>),"?),B[0D6`(``$D!QDP!\4V)[D6)[4DQUD0Q]DV)UD@!SDR)T4G![AM(
MP>$%3`GQB<E(`<Y,B<%)P>@"2,'A'D&)]DD)R$B+C"1@`@``2`'!20'-2(G1
MB=),,<%!,<Q+C4PE`$V)]$V)]4G![1M)P>0%30GL38G52<'J`DG!Y1Y%B>1-
M">I,BZPD:`(``$P!X4&)S$D!Q4P!ZDV)Q46)P$TQU40Q[DR-+#),B>),B>9(
MP>(%2,'N&T@)\HG220'53(GR2<'N`DC!XAY$B>Y)"=9(BY0D<`(``$@!PD@#
MA"1X`@``3`'"38G033'P1#'!28GP2`'*2(GQ2<'H&TC!X05,"<%%B=`!T4R)
MXDG![`)(P>(>20G42HT4"$B)R$D!T$R)\DC!X`5$`>-,,>)(B5\803'52XT4
M*$F)R`'I2<'H&TB)3PA,"<`!T$B)!TB)\$C![@)(P>`>2`G&00'S1`-W($R)
M7Q!,B7<@2(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^B4
MQ___#Q]``$B#[`B_@````.B2R/__NHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)
M4`A(B4@02,=`&'94,A!(B7`@2,=`*`````!(QT`P`````,=`>`````!(@\0(
MPV9F+@\?A```````D$%72&/"059)B<9!54%428G\54B-;SA32(GS2(/L"$B+
M=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%[0```$&#
M_C\/CBL!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=#Q]$``#S#V\#3(GG2(/#
M0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HX>C__TPYZW7,0<'G
M!D4I_DECQDB#^`AR7$F+50!)B50D.$F+5`7X2(E4!?A(C54(2(/B^$@IU4DI
M[4@!Q4B#Y?A(@_T(<AA(@^7X,<!)BTP%`$B)#`)(@\`(2#GH<NY%B70D>$B#
MQ`A;74%<05U!7D%?PV:0J`1U=$B%P'3A00^V50!!B%0D.*@"=--!#[=4!?YF
MB50%_NO&#Q]``$&]0````$B-?`4`2(G>02G%13GN10].[DUC_4R)^NBUQO__
M08M$)'A$`>A!B40D>(/X0'623(GG12GN3`'[Z`7H___IR_[__TF)W>DC____
M08M5`$&)5"0X08M4!?R)5`7\Z5O___^0059,C78X055!5%5(B?532(M&*$B)
M^T2+9BA$BVXP2,'H`X/@/T$/S$$/S8U(`4B8QD0&.(!(8\%,`?"#^3@/CB0!
M``"^0````"G.=`\QTHG1@\(!Q@0(`#GR<O-(B>_H?.?__V8/[\`/$44X2<=&
M,`````!!#Q%&$$$/$48@1(EM<$B)[T2)973H4N?__TB+10!(B>](P>@8B`-(
MBT4`2,'H$(A#`4B+10!(P>@(B$,"2(M%`(A#`TB+10A(P>@8B$,$2(M%"$C!
MZ!"(0P5(BT4(2,'H"(A#!DB+10B(0P=(BT402,'H&(A#"$B+11!(P>@0B$,)
M2(M%$$C!Z`B(0PI(BT40B$,+2(M%&$C!Z!B(0PQ(BT482,'H$(A##4B+11A(
MP>@(B$,.2(M%&(A##TB+12!(P>@8B$,02(M%($C!Z!"(0Q%(BT4@2,'H"(A#
M$DB+12"(0Q-;74%<05U!7NE+P___#Q\`NC@````Q_RG*@_H(<DJ)T4C'````
M``!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X+=_O__@^+X,<")QH/`
M"$B)/#$YT'+SZ<;^__\/'X0``````/;"!'4CA=(/A+'^___&``#VP@(/A*7^
M__\QR6:)3!#^Z9G^__\/'P#'``````#'1!#\`````.F#_O__#Q]$``!!5TR-
M/4=>``!!5DF)UD%528GU051!B?Q52(TM.%X``%-,*?U(@^P(Z%/"__](P?T#
M=!LQVP\?`$R)\DR)[D2)YT'_%-](@\,!2#G==>I(@\0(6UU!7$%=05Y!7\,/
M'P##9BX/'X0```````\?1```2(L-$6(``.F4P___2(/L"$B#Q`C#````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"X`+P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`$Q$7TQ)0E)!4EE?4$%4
M2`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`
M)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#4Q`"UE`"TM`````````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD
M;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU
M;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L
M<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P
M*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P``
M`````````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`1L#.P0!```?````H(+__U`!```@AO__>`$``#"&___T!0``0(C__R`!```P
MB?__D`$```"*___<`0``@(O__R`"```0C/__1`(``-",__]L`@``L(W__[`"
M``#PC____`(``&"0__\4`P``D)#__RP#``!0D?__8`,``&"1__]T`P``<)/_
M_]0#``"@D___Z`,``,"3___\`P``<)C__R@$``#PF/__1`0``!"9__]<!```
M()K__ZP$````HO__?`4``*"D__^P!0``X*7__R`&````O/__<`8``&"\__^(
M!@```+[__]0&````P/__&`<``&#`__]@!P``<,#__W@'````````%```````
M```!>E(``7@0`1L,!PB0`0<0%````!P````8A___*P``````````````%```
M```````!>E(``7@0`1L,!PB0`0``)````!P```!(@?__@`,````.$$8.&$H/
M"W<(@``_&CLJ,R0B`````!0```!$````H(3__P@``````````````$@```!<
M````F(?__\T`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y`
M`FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P!`````J````!R(__]T`0```$(.
M$(X"0@X8C0-"#B",!$$.*(8%00XP@P9'#M`!?@H.,$$.*$$.($(.&$(.$$(.
M"$L+`"````#L````6(G__XL`````00X0A@)2#K`!`G$*#A!!#@A!"R0````0
M`0``Q(G__[T`````00X0A@("6PH."$P+`D`*#@A!"T\."`!`````.`$``%R*
M___<`````$(.$(\"1PX8C@-"#B"-!$(.*(P%1`XPA@91#L`@`H(*#C!!#BA"
M#B!"#AA"#A!"#@A#"T@```!\`0``^(K__S$"````0@X0CP)"#AB.`T(.((T$
M0@XHC`5!#C"&!D0..(,'1PY0`Q4!"@XX00XP00XH0@X@0@X80@X00@X(10L4
M````R`$``.R,__]I`````$0.$`)@#@@4````X`$``$2-__\P`````$0.$%8.
M"``P````^`$``%R-__^_`````$(.$(P"00X8A@-!#B"#!$<.P$`"IPH.($0.
M&$$.$$(."$$+$````"P"``#HC?__!0````````!<````0`(``.2-__\"`@``
M`$(.$(\"0@X8C@-"#B"-!$4.*(P%00XPA@9+#CB#!T<.\"$"9`H..$$.,$$.
M*$(.($(.&$(.$$(."$0+`JX.^"%(#H`B8@[X(4$.\"$````0````H`(``)2/
M__\E`````````!````"T`@``L(___QP`````````*````,@"``"\C___I@0`
M``!!#A"&`D$.&(,#2PY@`T<$"@X800X000X(00L8````]`(``$"4__]T````
M`$0.(&T*#@A'"P``%````!`#``"DE/__'0````!$#A!8#@@`3````"@#``"L
ME/__"P$```!"#A",`D$.&(8#2PX@@P1$#C`"0@H.($H.&$$.$$(."$\+9`H.
M($$.&$$.$$(."$@+80XX20Y`8PXX00XP``#,````>`,``&R5___5!P```$(.
M$(\"0@X8C@-"#B"-!$P.*(P%00XPA@9!#CB#!T<.P(,"`ZP!#LB#`F$.T(,"
M7P[(@P)"#L"#`@)X"@XX1`XP00XH0@X@0@X80@X00@X(0@L#<0$.R(,"20[0
M@P)@#LB#`D$.P(,"6P[(@P)%#M"#`DX.V(,"30[@@P)+#L"#`@,%`0H..$0.
M,$$.*$(.($(.&$(.$$(."$T+`R(!#LB#`D0.T(,":`[(@P)!#L"#`@+K"@[(
M@P)!#M"#`D4+,````$@$``!\G/__G0(```!"#A"-`D(.&(P#00X@A@1$#C`#
MU@$*#B!!#AA"#A!"#@A$"T````!\!```Z)[__SX!````0@X0C`)!#AB&`T0.
M((,$1`XP`H(*#B!!#AA!#A!"#@A'"W0*#B!$#AA!#A!"#@A-"P``*````,`$
M```T@/__#P(```!"#A",`D$.&(8#1`Y0`Z0!"@X81`X00@X(00M,````[`0`
M`+B?__\<%@```$(.$(\"1@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#
M]Q4*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```!0````\!0``B+7__U0`````
M1`X0`D\."$@```!4!0``T+7__Y\!````0@X0CP)%#AB.`T4.((T$0@XHC`5$
M#C"&!D4..(,'1PY``N4*#CA!#C!!#BA"#B!"#AA"#A!"#@A#"P!`````H`4`
M`"2W___[`0```$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#2@$*#BA!#B!"
M#AA"#A!"#@A("P```````$0```#D!0``X+C__UT`````0@X0CP))#AB.`T4.
M((T$10XHC`5$#C"&!D@..(,'1PY`:@XX00XP00XH0@X@0@X80@X00@X(`!0`
M```L!@``^+C__P$``````````````!````!$!@``\+C__PP`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````*`F````````8"8````````!`````````/("
M`````````0`````````"`P````````$`````````$@,````````,````````
M```@````````#0````````#\70```````!D`````````T+L````````;````
M``````@`````````&@````````#8NP```````!P`````````"`````````#U
M_O]O``````@#````````!0`````````@#0````````8`````````"`0`````
M```*`````````)T$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````H!0```````!0`````````
M!P`````````7`````````(`4````````!P``````````$P````````@`````
M````@`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````(`2````````____;P`````"````````
M`/#__V\`````OA$```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#@NP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,```````"6(P``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$1E8FEA;B`Q,"XR+C`M,3DI(#$P+C(N,```+G-H<W1R=&%B`"YI;G1E
M<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN
M:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y
M`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@````````"H`@```````*@"
M````````'`````````````````````$````````````````````3````!P``
M``(`````````Q`(```````#$`@```````"0````````````````````$````
M````````````````)@````<````"`````````.@"````````Z`(````````@
M````````````````````!````````````````````#0```#V__]O`@``````
M```(`P````````@#````````_``````````%``````````@`````````````
M```````^````"P````(`````````"`0````````(!````````!@)````````
M!@````$````(`````````!@`````````1@````,````"`````````"`-````
M````(`T```````"=!````````````````````0```````````````````$X`
M``#___]O`@````````"^$0```````+X1````````P@`````````%````````
M``(``````````@````````!;````_O__;P(`````````@!(```````"`$@``
M`````(``````````!@````(````(````````````````````:@````0````"
M```````````3`````````!,```````"``0````````4`````````"```````
M```8`````````'0````$````0@````````"`%````````(`4````````*`4`
M```````%````%@````@`````````&`````````!^`````0````8`````````
M`"``````````(````````!<````````````````````$````````````````
M````>0````$````&`````````"`@````````("````````"``P``````````
M````````$``````````0`````````(0````!````!@````````"@(P``````
M`*`C````````"`````````````````````@`````````"`````````"-````
M`0````8`````````L",```````"P(P```````$PZ```````````````````0
M````````````````````DP````$````&`````````/Q=````````_%T`````
M```)````````````````````!````````````````````)D````!`````@``
M````````8`````````!@````````@#T``````````````````!``````````
M``````````"A`````0````(`````````@)T```````"`G0````````0!````
M```````````````$````````````````````KP````$````"`````````(B>
M````````B)X```````"(!@``````````````````"```````````````````
M`+D````.`````P````````#0NP```````-"K````````"```````````````
M``````@`````````"`````````#%````#P````,`````````V+L```````#8
MJP````````@````````````````````(``````````@`````````T0````8`
M```#`````````."[````````X*L````````0`@````````8`````````"```
M```````0`````````(@````!`````P````````#PO0```````/"M````````
M$`(```````````````````@`````````"`````````#:`````0````,`````
M`````,``````````L````````"`````````````````````(````````````
M````````X`````@````#`````````"#`````````(+````````"`$```````
M````````````(````````````````````.4````!````,```````````````
M`````""P````````'P````````````````````$``````````0`````````!
M`````P`````````````````````````_L````````.X`````````````````
2```!````````````````````
